@@ -15,9 +15,7 @@ class TemplateNotFoundError(DvcRenderException):
 
 class NoFieldInDataError(DvcRenderException):
     def __init__(self, field_name):
-        super().__init__(
-            f"Field '{field_name}' does not exist in provided data."
-        )
+        super().__init__(f"Field '{field_name}' does not exist in provided data.")
 
 
 class TemplateContentDoesNotMatch(DvcRenderException):
@@ -115,7 +113,11 @@ class BarHorizontalSortedTemplate(Template):
                 "sort": "-x",
             },
             "yOffset": {"field": "rev"},
-            "color": {"field": "rev", "type": "nominal"},
+            "color": {
+                "field": "rev",
+                "type": "nominal",
+                "legend": {"orient": "top", "direction": "vertical"},
+            },
         },
     }
 
@@ -143,7 +145,11 @@ class BarHorizontalTemplate(Template):
                 "title": Template.anchor("y_label"),
             },
             "yOffset": {"field": "rev"},
-            "color": {"field": "rev", "type": "nominal"},
+            "color": {
+                "field": "rev",
+                "type": "nominal",
+                "legend": {"orient": "top", "direction": "vertical"},
+            },
         },
     }
 
@@ -395,7 +401,11 @@ class ScatterTemplate(Template):
                         "title": Template.anchor("y_label"),
                         "scale": {"zero": False},
                     },
-                    "color": {"field": "rev", "type": "nominal"},
+                    "color": {
+                        "field": "rev",
+                        "type": "nominal",
+                        "legend": {"orient": "top", "direction": "vertical"},
+                    },
                 },
                 "layer": [
                     {"mark": "point"},
@@ -475,25 +485,50 @@ class SmoothLinearTemplate(Template):
         "params": [
             {
                 "name": "smooth",
-                "value": 0.2,
+                "value": 0.001,
                 "bind": {
                     "input": "range",
                     "min": 0.001,
                     "max": 1,
-                    "step": 0.01,
+                    "step": 0.001,
                 },
             },
         ],
-        "transform": [
-            {
-                "loess": Template.anchor("y"),
-                "on": Template.anchor("x"),
-                "groupby": ["rev"],
-                "bandwidth": {"signal": "smooth"},
-            }
-        ],
         "layer": [
             {
+                "mark": "line",
+                "encoding": {
+                    "x": {
+                        "field": Template.anchor("x"),
+                        "type": "quantitative",
+                        "title": Template.anchor("x_label"),
+                    },
+                    "y": {
+                        "field": Template.anchor("y"),
+                        "type": "quantitative",
+                        "title": Template.anchor("y_label"),
+                        "scale": {"zero": False},
+                    },
+                    "color": {
+                        "field": "rev",
+                        "type": "nominal",
+                        "legend": {"orient": "top", "direction": "vertical"},
+                    },
+                },
+                "transform": [
+                    {
+                        "loess": Template.anchor("y"),
+                        "on": Template.anchor("x"),
+                        "groupby": ["rev", "filename", "field", "filename::field"],
+                        "bandwidth": {"signal": "smooth"},
+                    },
+                ],
+            },
+            {
+                "mark": {
+                    "type": "point",
+                    "tooltip": {"content": "data"},
+                },
                 "encoding": {
                     "x": {
                         "field": Template.anchor("x"),
@@ -508,85 +543,18 @@ class SmoothLinearTemplate(Template):
                     },
                     "color": {"field": "rev", "type": "nominal"},
                 },
-                "layer": [
-                    {"mark": "line", "point": True},
-                    {
-                        "selection": {
-                            "label": {
-                                "type": "single",
-                                "nearest": True,
-                                "on": "mouseover",
-                                "encodings": ["x"],
-                                "empty": "none",
-                                "clear": "mouseout",
-                            }
-                        },
-                        "mark": "point",
-                        "encoding": {
-                            "opacity": {
-                                "condition": {
-                                    "selection": "label",
-                                    "value": 1,
-                                },
-                                "value": 0,
-                            }
-                        },
-                    },
-                ],
-            },
-            {
-                "transform": [{"filter": {"selection": "label"}}],
-                "layer": [
-                    {
-                        "mark": {"type": "rule", "color": "gray"},
-                        "encoding": {
-                            "x": {
-                                "field": Template.anchor("x"),
-                                "type": "quantitative",
-                            }
-                        },
-                    },
-                    {
-                        "encoding": {
-                            "text": {
-                                "type": "quantitative",
-                                "field": Template.anchor("y"),
-                            },
-                            "x": {
-                                "field": Template.anchor("x"),
-                                "type": "quantitative",
-                            },
-                            "y": {
-                                "field": Template.anchor("y"),
-                                "type": "quantitative",
-                            },
-                        },
-                        "layer": [
-                            {
-                                "mark": {
-                                    "type": "text",
-                                    "align": "left",
-                                    "dx": 5,
-                                    "dy": -5,
-                                },
-                                "encoding": {
-                                    "color": {
-                                        "type": "nominal",
-                                        "field": "rev",
-                                    }
-                                },
-                            }
-                        ],
-                    },
-                ],
             },
         ],
     }
 
 
-class LinearTemplate(Template):
+class LinearTemplate(SmoothLinearTemplate):
     DEFAULT_NAME = "linear"
 
+
+class SimpleLinearTemplate(Template):
+    DEFAULT_NAME = "simple"
+
     DEFAULT_CONTENT = {
         "$schema": "https://vega.github.io/schema/vega-lite/v5.json",
         "data": {"values": Template.anchor("data")},
@@ -595,7 +563,6 @@ class LinearTemplate(Template):
         "height": 300,
         "mark": {
             "type": "line",
-            "point": True,
             "tooltip": {"content": "data"},
         },
         "encoding": {
@@ -610,15 +577,15 @@ class LinearTemplate(Template):
                 "title": Template.anchor("y_label"),
                 "scale": {"zero": False},
             },
-            "color": {"field": "rev", "type": "nominal"},
+            "color": {
+                "field": "rev",
+                "type": "nominal",
+                "legend": {"orient": "top", "direction": "vertical"},
+            },
         },
     }
 
 
-class SimpleLinearTemplate(LinearTemplate):
-    DEFAULT_NAME = "simple"
-
-
 TEMPLATES = [
     SimpleLinearTemplate,
     LinearTemplate,
@@ -693,9 +660,7 @@ def dump_templates(output: "StrPath", targets: Optional[List] = None) -> None:
 
     if targets:
         templates = [
-            template
-            for template in TEMPLATES
-            if template.DEFAULT_NAME in targets
+            template for template in TEMPLATES if template.DEFAULT_NAME in targets
         ]
     else:
         templates = TEMPLATES
@@ -707,8 +672,6 @@ def dump_templates(output: "StrPath", targets: Optional[List] = None) -> None:
         if path.exists():
             content = path.read_text(encoding="utf-8")
             if content != template.content:
-                raise TemplateContentDoesNotMatch(
-                    template.DEFAULT_NAME or "", path
-                )
+                raise TemplateContentDoesNotMatch(template.DEFAULT_NAME or "", path)
         else:
             path.write_text(template.content, encoding="utf-8")
